@@ -110,12 +110,7 @@ class Router:
         
         # Try to load model from config if not provided
         if model is None:
-            try:
-                config = UserConfig.load_config()
-                model = config.get("router", {}).get("default_model", "llama-3.3-70b-versatile")
-            except Exception as e:
-                logger.warning(f"Failed to load router default model from config.json: {e}")
-                model = "llama-3.3-70b-versatile"  # Fallback to default
+            model = "gpt-4o"  # Fallback to default
         
         self.model = model
         self.client = StructuredOutputClient(model=model)
